# Contributing

To get setup in the environment and run the tests, take the following steps:

```bash
python3 -m venv env
source env/bin/activate
python3 -m pip install -e '.[dev]'
python3 -m pip install pre-commit
```

## Test Coverage

Pull requests that make changes or additions that are not covered by tests
will likely be closed without review.
